@@ -1,11 +1,9 @@
 use ZHOUYI;
-use utf8
-binmode STDOUT, ":utf8";
+use Encode;
 
 
 my ( $num1, $mum2 )=@ARGV;
 
-#print "$num1 $mum2";
 
 my $reply = ZhouyiEx( ZYindex( $mum2, $num1 ));
 my $reply1=outGua($reply);
@@ -14,11 +12,11 @@ my $replytuan=outtuan($reply);
 my $replyxiang=outxiang($reply);
 
 
-print $reply1,"\n";
+print encode_utf8($reply1),"\n";
 print "===六爻==\n\n";
-print $replyyao,"\n";
+print encode_utf8($replyyao),"\n";
 print "===彖辞==\n\n";
-print $replytuan,"\n";
+print encode_utf8($replytuan),"\n";
 print "===象传==\n\n";
-print $replyxiang,"\n";
+print encode_utf8($replyxiang),"\n";
 
