@@ -1,13 +1,12 @@
 package ZHOUYI;
-
-require Exporter;
 use utf8;
+require Exporter;
 use strict;
 use warnings;
 
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(ZhouyiEx ZYindex outGua sixyao outtuan outxiang maixyao maixiang);
-
+=encoding utf8
 =head1 NAME
 
 ZHOUYI - The ZHOUYI is module interpreter and outer the Chinese ancient
@@ -15,17 +14,14 @@ philosophy of The Book of Change(易经);
 
 =head1 VERSION
 
-Version 0.07
+Version 0.11
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
 
     use ZHOUYI;
 
@@ -35,12 +31,30 @@ Perhaps a little code snippet.
 
 =head1 EXPORT
 
+ZhouyiEx ZYindex outGua sixyao outtuan outxiang maixyao maixiang
+
 A list of functions that can be exported.  You can delete this section
 if you don't export anything, such as for a purely object-oriented module.
 
 
 =head1 SUBROUTINES/METHODS
 
+=head2 ZHouYiEx
+
+return YI info
+
+=head2 ZYindex
+
+return YI index of 1~81 gua.
+
+=head2 outGua outtuan sixyao outxiang
+
+return special  gua's info of 卦体，爻,彖传，象辞.
+
+=head2 maixyao maixiang
+
+return special yao's info of 爻,象辞, and the it's array. 
+
 =cut
 
 my ( $ZYdb, @ZYdb );
@@ -237,8 +251,7 @@ L<http://search.cpan.org/dist/ZHOUYI/>
 
 Copyright 2016 orange.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). 
+This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
 
@@ -260,7 +273,14 @@ __DATA__
 上九：亢龍有悔。
 用九：見群龍無首，吉。
 《彖》曰：大哉乾元，萬物資始，乃統天。云行雨施，品物流形。大明始終，六位時成，時乘六龍以御天。乾道變化，各正性命，保合大和，乃利貞。首出庶物，萬國咸寧。
-《象》曰：天行健，君子以自強不息。潛龍勿用，陽在下也。見龍在田，德施普也。終日乾乾，反復道也。或躍在淵，進無咎也。飛龍在天，大人造也。亢龍有悔，盈不可久也。用九，天德不可為首也。
+《象》曰：天行健，君子以自強不息。
+《象》曰：潛龍勿用，陽在下也。
+《象》曰：見龍在田，德施普也。
+《象》曰：終日乾乾，反復道也。
+《象》曰：或躍在淵，進無咎也。
+《象》曰：飛龍在天，大人造也。
+《象》曰：亢龍有悔，盈不可久也。
+《象》曰：用九，天德不可為首也。
 《文言》曰：「元者，善之長也。亨者，嘉之會也。利者，義之和也。貞者，事之干也。君子體仁足以長人。嘉會足以合禮。利物足以和義。貞固足以干事。君子行此四者，故曰『乾，元亨利貞。』」
 初九曰「潛龍勿用」，何謂也？
 子曰：「龍德而隱者也。不易乎世，不成乎名，遯世而無悶，不見是而無悶。樂則行之，憂則違之，確乎其不可拔，乾龍也。」
